pkg

package
v0.0.0-...-4cc0970 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 20, 2023 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ServerConfig

type ServerConfig struct {
	// contains filtered or unexported fields
}

Configure any server settings, ie if you want to host this somewhere You could change this to have the URL or a secret or something

func (*ServerConfig) GetPort

func (cfg *ServerConfig) GetPort() string

Directories

Path Synopsis

Jump to