Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ServerConfig ¶
type ServerConfig struct {
// contains filtered or unexported fields
}
Configure any server settings, ie if you want to host this somewhere You could change this to have the URL or a secret or something
func (*ServerConfig) GetPort ¶
func (cfg *ServerConfig) GetPort() string
Click to show internal directories.
Click to hide internal directories.